@@ -7,10 +7,11 @@ try:
     import json
 except ImportError:
     import simplejson as json
-    
+
 import socket
 import sys
 import time
+import traceback
 import urllib
 import urllib2
 import xmlrpclib
@@ -21,7 +22,8 @@ from clip2zeus.config import *
 
 class Clip2ZeusApp(object):
 
-    EXPOSED = ('help', 'get_version', 'get_interval', 'set_interval', 'shorten_urls', 'quit')
+    EXPOSED = ('help', 'get_version', 'get_interval', 'set_interval',
+               'shorten_urls', 'quit', 'get_api_key', 'set_api_key')
 
     def __init__(self, port=DEFAULT_PORT):
         """Creates the container for common functionality"""
@@ -37,7 +39,11 @@ class Clip2ZeusApp(object):
         self.server = None
         self._has_connection = False
         self.last_check = None
-        self.interval = config.get('main', 'interval', 1)
+        self.interval = config.getint('main', 'interval', 1)
+        self.api_key = config.get('main', 'api_key', '').replace('|', ':')
+
+        logging.debug('API Key: %s' % self.api_key)
+
         self.threshold = timedelta(seconds=HEARTBEAT_INT)
         socket.setdefaulttimeout(TIMEOUT_SEC)
 
@@ -208,7 +214,9 @@ class Clip2ZeusApp(object):
                 # Try to shorten this URL using 2ze.us
                 params = urllib.urlencode({
                     'url': url,
+                    'api': self.api_key,
                 })
+                logger.debug('Request: %s' % params)
 
                 try:
                     logger.info(' - %s' % url)
@@ -225,10 +233,13 @@ class Clip2ZeusApp(object):
                     except (ValueError, ):
                         usable = None
 
-                if usable and usable['urls'].get(url, None):
-                    short = usable['urls'][url]['shortcut']
+                if usable and usable.get('url', None):
+                    short = usable['url']['shortcut']
                     logger.info('   -> %s' % short)
-                    data = data.replace(url, short)
+                    try:
+                        data = data.replace(url, short)
+                    except:
+                        logger.debug('An error occurred: %s' % traceback.format_exc())
 
         self.data = data
 
@@ -236,6 +247,19 @@ class Clip2ZeusApp(object):
             logger.debug('Updating clipboard')
             self.update_clipboard(self.data)
 
+    def get_api_key(self):
+        """Returns the user's API key"""
+
+        logger.debug('API key requested by client: %s' % (self.api_key,))
+        return self.api_key
+
+    def set_api_key(self, api_key):
+        """Sets the user's API key"""
+
+        logger.debug('API key updated by client: %s' % (api_key,))
+        self.api_key = api_key
+        config.set('main', 'api_key', api_key.replace(':', '|'))
+
     def quit(self):
         """Ends processing"""
 
